@@ -58,7 +58,5 @@ int main(int argc,char **argv)
 	    perror("ioctl CLIP_NULENCAP");
 	    return 1;
 	}
-    printf("OK\n");
-    pause();
     return 0;
 }
